from prefect import flow

from prefect_sns.tasks import goodbye_prefect_sns, hello_prefect_sns


def test_hello_prefect_sns():
    @flow
    def test_flow():
        return hello_prefect_sns()

    result = test_flow()
    assert result == "Hello, prefect-sns!"


def goodbye_hello_prefect_sns():
    @flow
    def test_flow():
        return goodbye_prefect_sns()

    result = test_flow()
    assert result == "Goodbye, prefect-sns!"



"""This is an example flows module"""
from prefect import flow

from prefect_sns.blocks import SnsBlock
from prefect_sns.tasks import goodbye_prefect_sns, hello_prefect_sns


@flow
def hello_and_goodbye():
    """
    Sample flow that says hello and goodbye!
    """
    SnsBlock.seed_value_for_example()
    block = SnsBlock.load("sample-block")

    print(hello_prefect_sns())
    print(f"The block's value: {block.sns_arn}")
    print(goodbye_prefect_sns())
    return "Done"


if __name__ == "__main__":
    hello_and_goodbye()



"""This is an example tasks module"""
from prefect import task


@task
def hello_prefect_sns() -> str:
    """
    Sample task that says hello!

    Returns:
        A greeting for your collection
    """
    return "Hello, prefect-sns!"


@task
def goodbye_prefect_sns() -> str:
    """
    Sample task that says goodbye!

    Returns:
        A farewell for your collection
    """
    return "Goodbye, prefect-sns!"
